@@ -4,6 +4,6 @@ __author__ = "Sk Farhad"
 __copyright__ = "Copyright (c) 2021 The Python Packaging Authority"
 
 
-import dse_data_loader
 from .dse_data_loader import PriceData
 from .dse_data_loader import FundamentalData
+from .dse_data_loader import CandlestickPlot
